@@ -7,9 +7,6 @@ from bs4 import BeautifulSoup
 import requests
 import sys
 
-# 该程序设置了运行参数,主程序不再改动，从数组第二个参数开始设置，分别为书本章节目录地址 小说名字
-sys.argv =[sys.argv[0],'https://www.vbiquge.com/76_76449/','万界天尊']
-
 def getOneChapter(url):
     try:
         r= requests.get(url)
@@ -20,13 +17,12 @@ def getOneChapter(url):
     tag_div_contents=soup.body.find_all(attrs={'id':'content'})[0]
     return tag_div_contents.text.replace('    ','\n')#.replace('\xa0','')
 
-def main():
-    path='D://'+sys.argv[2]+'.txt'
+def main(url='https://www.vbiquge.com/76_76449/',name='万界天尊'):
+    path='D://'+name+'.txt'
     # 文件默认的是gkb编码，而页面编码是utf-8，所以会产生部分字符转换异常的情况，需统一
     file=open(path,'w',encoding='utf-8')
     pre_url='https://www.vbiquge.com'
     # 目录地址
-    url=sys.argv[1]
     r= requests.get(url)
     r.encoding='utf-8'
     soup=BeautifulSoup(r.text,'lxml')
