@@ -9,11 +9,8 @@ from urllib.request import urlretrieve
 import os
 import sys
 
-# 该程序设置了运行参数,主程序不再改动，从数组第二个参数开始设置，分别为漫画章节目录地址 漫画名字
-sys.argv =[sys.argv[0],'https://www.dmzj.com/info/yaoshenji.html','妖神记']
-
 # 爬取一章的漫画图片
-def getOneChapter(url,chapterName):
+def getOneChapter(url,chapterName,name):
     r= requests.get(url)
     r.encoding='utf-8'
     soup=BeautifulSoup(r.text,'lxml')
@@ -29,14 +26,14 @@ def getOneChapter(url,chapterName):
     pic_name=1
     for str_third_url in str_third_urls:
         url_pic='https://images.dmzj1.com/img/chapterpic/'+str_first_url+'/'+str_second_url+'/'+str_third_url+'.jpg'
-        downloadPic(url_pic,chapterName,pic_name)
+        downloadPic(url_pic,chapterName,pic_name,name)
         pic_name=pic_name+1
 
 # 下载该url下的图片
-def downloadPic(url_pic,chapterName,pic_name):
+def downloadPic(url_pic,chapterName,pic_name,name):
     # 因为windows下有一些特殊字符不能作为目录名，所以需剔除
     chapterName=re.sub('[.|\\|/|:|*|?|"|<|>|\|]','',chapterName)
-    path='D://{}/{}'.format(sys.argv[2],chapterName)
+    path='D://{}/{}'.format(name,chapterName)
     # 因为不能写入未创建的目录，所以需要先创建目录
     mkdir(path)
     # 防止连接断开，进行重连操作
@@ -51,9 +48,7 @@ def mkdir(path):
     if not os.path.exists(path):
         os.makedirs(path.encode('utf-8'))
 
-def main():
-    #目录地址
-    url=sys.argv[1]
+def main(url='https://www.dmzj.com/info/yaoshenji.html',name='妖神记'):
     r= requests.get(url)
     r.encoding='utf-8'
     soup=BeautifulSoup(r.text,'lxml')
@@ -66,5 +61,5 @@ def main():
         str_url_chapter=tag_a_allChapter.attrs['href']
         # 章节名称
         str_title_chapter=tag_a_allChapter.find_all('span',attrs={'class':'list_con_zj'})[0].text
-        getOneChapter(str_url_chapter,str_title_chapter)
+        getOneChapter(str_url_chapter,str_title_chapter,name)
         print(str_title_chapter+'\t'+'下载完成。')
\ No newline at end of file
