@@ -40,22 +40,26 @@ headers = {
 
 
 def main():
-    options=webdriver.ChromeOptions()
-    for header in headers:
-        options.add_argument('{}="{}"'.format(header,headers[header]))
-    driver=webdriver.Chrome('D://谷歌驱动/chromedriver.exe')
-    driver.get('https://cart.taobao.com/cart.htm?spm=a1z02.1.1997525049.1.U6BJfg&from=mini&ad_id=&am_id=&cm_id=&pm_id=1501036000a02c5c3739')
+    try:
+        options=webdriver.ChromeOptions()
+        for header in headers:
+            options.add_argument('{}="{}"'.format(header,headers[header]))
+        driver=webdriver.Chrome('D://谷歌驱动/chromedriver.exe')
+        driver.get('https://cart.taobao.com/cart.htm?spm=a1z02.1.1997525049.1.U6BJfg&from=mini&ad_id=&am_id=&cm_id=&pm_id=1501036000a02c5c3739')
 
-    username=driver.find_element_by_xpath('//*[@id="fm-login-id"]')
-    username.send_keys(Taobao[0])
-    password=driver.find_element_by_xpath('//*[@id="fm-login-password"]')
-    password.send_keys(Taobao[1])
-    password.send_keys(Keys.RETURN)
+        username=driver.find_element_by_xpath('//*[@id="fm-login-id"]')
+        username.send_keys(Taobao[0])
+        password=driver.find_element_by_xpath('//*[@id="fm-login-password"]')
+        password.send_keys(Taobao[1])
+        password.send_keys(Keys.RETURN)
 
-    time.sleep(5)
-    print(driver.get_cookies())
+        time.sleep(5)
+        print(driver.get_cookies())
 
-    path='D://SampleSprider/'
-    os.makedirs(path,exist_ok=True)
-    with open(path+'taobao_cookies.txt','w') as file:
-        file.write(driver.get_cookies().__str__())
+        path='D://SampleSprider/'
+        os.makedirs(path,exist_ok=True)
+        with open(path+'taobao_cookies.txt','w') as file:
+            file.write(driver.get_cookies().__str__())
+        driver.quit()
+    except BaseException:
+        main()
